@@ -32,6 +32,7 @@ describe 'tempest' do
 
       it 'configures image_ref' do
         is_expected.to contain_tempest_config('compute/image_ref').with_value('4c423fc6-87f7-4e6d-9d3c-abc13058ae5b')
+        is_expected.to contain_tempest_config('heat_plugin/minimal_image_ref').with_value('4c423fc6-87f7-4e6d-9d3c-abc13058ae5b')
       end
     end
 
@@ -42,7 +43,8 @@ describe 'tempest' do
       end
 
       it 'uses a resource to configure image_ref from image_name' do
-        is_expected.to contain_tempest_glance_id_setter('image_ref').with_image_name('cirros')
+        is_expected.to contain_tempest_glance_id_setter('compute/image_ref').with_image_name('cirros')
+        is_expected.to contain_tempest_glance_id_setter('heat_plugin/minimal_image_ref').with_image_name('cirros')
       end
     end
 
@@ -77,7 +79,7 @@ describe 'tempest' do
       end
 
       it 'uses a resource to configure public_network_id from public_network_name' do
-        is_expected.to contain_tempest_neutron_net_id_setter('public_network_id').with_network_name('public')
+        is_expected.to contain_tempest_neutron_net_id_setter('network/public_network_id').with_network_name('public')
       end
     end
 
@@ -149,6 +151,7 @@ describe 'tempest' do
         { :configure_images    => true,
           :image_name          => 'image name',
           :image_name_alt      => 'image name alt',
+          :heat_image_name     => 'heat image name',
           :public_network_name => 'network name',
           :neutron_available   => true,
           :install_from_source => true,
@@ -184,7 +187,7 @@ describe 'tempest' do
 
           is_expected.to contain_vcsrepo('/var/lib/tempest').with(
             :ensure   => 'present',
-            :source   => 'git://github.com/openstack/tempest.git',
+            :source   => 'https://opendev.org/openstack/tempest',
             :revision => nil,
             :provider => 'git',
             :require  => 'Package[git]',
@@ -195,58 +198,62 @@ describe 'tempest' do
         it { should contain_class('openstacklib::openstackclient') }
 
         it 'configure tempest config' do
-          is_expected.to contain_tempest_config('auth/admin_domain_name').with(:value => nil)
+          is_expected.to contain_tempest_config('auth/admin_domain_name').with(:value => '<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('auth/admin_project_domain_name').with(:value => '<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('auth/admin_user_domain_name').with(:value => '<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('auth/default_credentials_domain_name').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('auth/admin_password').with_secret( true )
           is_expected.to contain_tempest_config('auth/admin_project_name').with(:value => nil)
           is_expected.to contain_tempest_config('auth/admin_username').with(:value => nil)
+          is_expected.to contain_tempest_config('auth/admin_system').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('auth/tempest_roles').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('auth/use_dynamic_credentials').with(:value => nil)
-          is_expected.to contain_tempest_config('dns/nameservers').with(:value => nil)
-          is_expected.to contain_tempest_config('compute/change_password_available').with(:value => nil)
           is_expected.to contain_tempest_config('compute/flavor_ref').with(:value => nil)
           is_expected.to contain_tempest_config('compute/flavor_ref_alt').with(:value => nil)
-          is_expected.to contain_tempest_config('compute/image_alt_ssh_user').with(:value => nil)
           is_expected.to contain_tempest_config('compute/image_ref').with(:value => nil)
           is_expected.to contain_tempest_config('compute/image_ref_alt').with(:value => nil)
           is_expected.to contain_tempest_config('compute/build_interval').with(:value => nil)
           is_expected.to contain_tempest_config('compute-feature-enabled/attach_encrypted_volume').with(:value => false)
           is_expected.to contain_tempest_config('compute-feature-enabled/resize').with(:value => false)
-          is_expected.to contain_tempest_config('baremetal/driver').with(:value => 'fake')
-          is_expected.to contain_tempest_config('baremetal/enabled_hardware_types').with(:value => 'ipmi')
           is_expected.to contain_tempest_config('validation/image_ssh_user').with(:value => nil)
+          is_expected.to contain_tempest_config('validation/image_alt_ssh_user').with(:value => nil)
           is_expected.to contain_tempest_config('validation/run_validation').with(:value => false)
+          is_expected.to contain_tempest_config('validation/ssh_key_type').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('identity/admin_role').with(:value => nil)
           is_expected.to contain_tempest_config('identity/auth_version').with(:value => 'v3')
           is_expected.to contain_tempest_config('identity/alt_password').with(:value => nil)
           is_expected.to contain_tempest_config('identity/alt_password').with_secret( true )
           is_expected.to contain_tempest_config('identity/alt_project_name').with(:value => nil)
           is_expected.to contain_tempest_config('identity/alt_username').with(:value => nil)
+          is_expected.to contain_tempest_config('identity/alt_project_domain_name').with(:value => '<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('identity/alt_user_domain_name').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('identity/password').with(:value => nil)
           is_expected.to contain_tempest_config('identity/password').with_secret( true )
           is_expected.to contain_tempest_config('identity/project_name').with(:value => nil)
+          is_expected.to contain_tempest_config('identity/username').with(:value => nil)
+          is_expected.to contain_tempest_config('identity/project_domain_name').with(:value => '<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('identity/user_domain_name').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('identity/uri').with(:value => nil)
           is_expected.to contain_tempest_config('identity/uri_v3').with(:value => nil)
-          is_expected.to contain_tempest_config('identity/username').with(:value => nil)
           is_expected.to contain_tempest_config('identity/ca_certificates_file').with(:value => nil)
           is_expected.to contain_tempest_config('identity/disable_ssl_certificate_validation').with(:value => nil)
-          is_expected.to contain_tempest_config('identity-feature-enabled/api_v2').with(:value => false)
           is_expected.to contain_tempest_config('identity-feature-enabled/api_v3').with(:value => true)
-          is_expected.to contain_tempest_config('image-feature-enabled/api_v1').with(:value => true)
-          is_expected.to contain_tempest_config('image-feature-enabled/api_v2').with(:value => true)
+          is_expected.to contain_tempest_config('image-feature-enabled/api_v1').with(:value => '<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('image-feature-enabled/api_v2').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('l2gw/l2gw_switch').with(:value => nil)
-          is_expected.to contain_tempest_config('network-feature-enabled/api_extensions').with(:value => nil)
+          is_expected.to contain_tempest_config('network-feature-enabled/api_extensions').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('network/public_network_id').with(:value => nil)
           is_expected.to contain_tempest_config('network/public_router_id').with(:value => '')
           is_expected.to contain_tempest_config('dashboard/login_url').with(:value => nil)
           is_expected.to contain_tempest_config('dashboard/dashboard_url').with(:value => nil)
-          is_expected.to contain_tempest_config('database/db_flavor_ref').with_value('<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('database/db_flavor_ref').with(:value => nil)
           is_expected.to contain_tempest_config('service_available/cinder').with(:value => true)
           is_expected.to contain_tempest_config('volume-feature-enabled/backup').with(:value => false)
           is_expected.to contain_tempest_config('service_available/glance').with(:value => true)
           is_expected.to contain_tempest_config('service_available/heat').with(:value => false)
           is_expected.to contain_tempest_config('service_available/ceilometer').with(:value => false)
           is_expected.to contain_tempest_config('service_available/aodh').with(:value => false)
-          is_expected.to contain_tempest_config('service_available/aodh_plugin').with(:value => false)
+          is_expected.to contain_tempest_config('service_available/aodh_plugin').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('service_available/bgpvpn').with(:value => false)
           is_expected.to contain_tempest_config('service_available/gnocchi').with(:value => false)
           is_expected.to contain_tempest_config('service_available/horizon').with(:value => true)
@@ -265,37 +272,83 @@ describe 'tempest' do
           is_expected.to contain_tempest_config('service_available/designate').with(:value => false)
           is_expected.to contain_tempest_config('service_available/octavia').with(:value => false)
           is_expected.to contain_tempest_config('service_available/barbican').with(:value => false)
-          is_expected.to contain_tempest_config('whitebox/db_uri').with(:value => nil)
+          is_expected.to contain_tempest_config('service_available/manila').with(:value => false)
+          is_expected.to contain_tempest_config('enforce_scope/cinder').with(:value => '<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('enforce_scope/glance').with(:value => '<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('enforce_scope/keystone').with(:value => '<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('identity-feature-enabled/enforce_scope').with(:value => '<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('enforce_scope/neutron').with(:value => '<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('enforce_scope/nova').with(:value => '<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('dns/nameservers').with(:value => '<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('heat_plugin/auth_url').with(:value => nil)
+          is_expected.to contain_tempest_config('heat_plugin/auth_version').with(:value => '3')
+          is_expected.to contain_tempest_config('heat_plugin/admin_password').with_secret( true )
+          is_expected.to contain_tempest_config('heat_plugin/admin_project_name').with(:value => nil)
+          is_expected.to contain_tempest_config('heat_plugin/admin_username').with(:value => nil)
+          is_expected.to contain_tempest_config('heat_plugin/admin_project_domain_name').with(:value => '<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('heat_plugin/admin_user_domain_name').with(:value => '<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('heat_plugin/password').with(:value => nil)
+          is_expected.to contain_tempest_config('heat_plugin/password').with_secret( true )
+          is_expected.to contain_tempest_config('heat_plugin/project_name').with(:value => nil)
+          is_expected.to contain_tempest_config('heat_plugin/username').with(:value => nil)
+          is_expected.to contain_tempest_config('heat_plugin/image_ref').with(:value => nil)
+          is_expected.to contain_tempest_config('heat_plugin/instance_type').with(:value => nil)
+          is_expected.to contain_tempest_config('heat_plugin/minimal_image_ref').with(:value => nil)
+          is_expected.to contain_tempest_config('heat_plugin/minimal_instance_type').with(:value => nil)
+          is_expected.to contain_tempest_config('baremetal/driver').with(:value => 'fake')
+          is_expected.to contain_tempest_config('baremetal/enabled_hardware_types').with(:value => 'ipmi')
+          is_expected.to contain_tempest_config('load_balancer/member_role').with(:value => '<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('load_balancer/admin_role').with(:value => '<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('load_balancer/observer_role').with(:value => '<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('load_balancer/global_observer_role').with(:value => '<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('load_balancer/test_with_noop').with(:value => '<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('share/multitenancy_enabled').with(:value => '<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('share/enable_protocols').with(:value => '<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('share/multi_backend').with(:value => '<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('share/capability_storage_protocol').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('cli/cli_dir').with(:value => nil)
-          is_expected.to contain_tempest_config('oslo_concurrency/lock_path').with(:value => '/var/lib/tempest')
+          is_expected.to contain_oslo__concurrency('tempest_config').with(
+            :lock_path => '/var/lib/tempest'
+          )
           is_expected.to contain_tempest_config('scenario/img_file').with(:value => '/var/lib/tempest/cirros-0.4.0-x86_64-disk.img')
+          is_expected.to contain_tempest_config('scenario/img_disk_format').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('service_broker/run_service_broker_tests').with(:value => false)
           is_expected.to contain_oslo__log('tempest_config').with(
-              :debug => false,
-              :log_file => '<SERVICE DEFAULT>',
-              :use_stderr => true,
-              :use_syslog => false,
-              :logging_context_format_string => '<SERVICE DEFAULT>')
+            :debug => false,
+            :log_file => '<SERVICE DEFAULT>',
+            :use_stderr => true,
+            :use_syslog => false,
+            :logging_context_format_string => '<SERVICE DEFAULT>'
+          )
 
           is_expected.not_to contain_tempest_config('magnum/keypair_id').with_value('default')
         end
 
         it 'set glance id' do
-          is_expected.to contain_tempest_glance_id_setter('image_ref').with(
+          is_expected.to contain_tempest_glance_id_setter('compute/image_ref').with(
             :ensure            => 'present',
             :tempest_conf_path => '/var/lib/tempest/etc/tempest.conf',
             :image_name        => 'image name',
           )
-
-          is_expected.to contain_tempest_glance_id_setter('image_ref_alt').with(
+          is_expected.to contain_tempest_glance_id_setter('compute/image_ref_alt').with(
             :ensure            => 'present',
             :tempest_conf_path => '/var/lib/tempest/etc/tempest.conf',
             :image_name        => 'image name alt',
           )
+          is_expected.to contain_tempest_glance_id_setter('heat_plugin/image_ref').with(
+            :ensure            => 'present',
+            :tempest_conf_path => '/var/lib/tempest/etc/tempest.conf',
+            :image_name        => 'heat image name',
+          )
+          is_expected.to contain_tempest_glance_id_setter('heat_plugin/minimal_image_ref').with(
+            :ensure            => 'present',
+            :tempest_conf_path => '/var/lib/tempest/etc/tempest.conf',
+            :image_name        => 'image name',
+          )
         end
 
         it 'neutron net id' do
-          is_expected.to contain_tempest_neutron_net_id_setter('public_network_id').with(
+          is_expected.to contain_tempest_neutron_net_id_setter('network/public_network_id').with(
             :ensure            => 'present',
             :tempest_conf_path => '/var/lib/tempest/etc/tempest.conf',
             :network_name      => 'network name',
@@ -304,16 +357,16 @@ describe 'tempest' do
 
         it 'sets up virtualenv for tempest' do
           is_expected.to contain_exec('setup-venv').with(
-              :command => "virtualenv -p python3 /var/lib/tempest/.venv && /var/lib/tempest/.venv/bin/#{platform_params[:pip_command]} install -U -r requirements.txt",
-              :cwd     => '/var/lib/tempest',
-              :unless  => 'test -d /var/lib/tempest/.venv',
-              :path    => ['/bin', '/usr/bin', '/usr/local/bin']
+            :command => "virtualenv -p python3 /var/lib/tempest/.venv && /var/lib/tempest/.venv/bin/#{platform_params[:pip_command]} install -U -r requirements.txt",
+            :cwd     => '/var/lib/tempest',
+            :unless  => 'test -d /var/lib/tempest/.venv',
+            :path    => ['/bin', '/usr/bin', '/usr/local/bin']
           )
         end
       end
     end
 
-    context 'with deprecated img_dir parameter and img_file set' do
+    context 'with img_file set' do
       let :params do
         { :image_name     => 'cirros',
           :image_name_alt => 'cirros' ,
@@ -325,67 +378,82 @@ describe 'tempest' do
       end
     end
 
-    context 'with deprecated img_dir parameter set' do
-      let :params do
-        { :image_name     => 'cirros',
-          :image_name_alt => 'cirros',
-          :img_dir        => '/home/stack' }
-      end
-
-      it 'sets image_file based on img_dir' do
-        is_expected.to contain_tempest_config('scenario/img_file').with(:value => '/home/stack/cirros-0.4.0-x86_64-disk.img')
-      end
-    end
-
-    context 'with deprecated img_dir parameter and img_file set' do
-      let :params do
-        { :image_name     => 'cirros',
-          :image_name_alt => 'cirros',
-          :img_dir        => '/home/stack',
-          :img_file       => 'myimage.img' }
-      end
-
-      it 'sets image_file based on img_dir and img_file' do
-        is_expected.to contain_tempest_config('scenario/img_file').with(:value => '/home/stack/myimage.img')
-      end
-    end
-
     context 'install Tempest from package' do
       let :params do
-        {:install_from_source => false,
-        :image_name           => 'image name',
-        :image_name_alt       => 'image name alt'}
+        { :install_from_source  => false,
+          :image_name           => 'image name',
+          :image_name_alt       => 'image name alt' }
       end
 
       it 'checks for tempest package' do
-          is_expected.to contain_package('tempest').with(
-            :ensure => 'present',
-            :name   => platform_params[:package_name],
-            :tag    => ['openstack', 'tempest-package'],
-          )
+        is_expected.to contain_package('tempest').with(
+          :ensure => 'present',
+          :name   => platform_params[:package_name],
+          :tag    => ['openstack', 'tempest-package'],
+        )
       end
       it 'creates tempest workspace' do
-          is_expected.to contain_exec('tempest-workspace').with(
-            :command     => 'tempest init /var/lib/tempest',
-            :path        => ['/bin', '/usr/bin'],
-            :refreshonly => true,
-            :require     => 'Package[tempest]'
-       )
+        is_expected.to contain_exec('tempest-workspace').with(
+          :command     => 'tempest init /var/lib/tempest',
+          :path        => ['/bin', '/usr/bin'],
+          :refreshonly => true,
+          :require     => 'Package[tempest]'
+        )
       end
     end
 
     context 'tempest workspace customization' do
       let :params do
-        {:tempest_workspace => '/tmp/tempest',
-         :image_name        => 'image name',
-         :image_name_alt    => 'image name alt',
-         :install_from_source => false}
+        { :tempest_workspace   => '/tmp/tempest',
+          :image_name          => 'image name',
+          :image_name_alt      => 'image name alt',
+          :install_from_source => false }
       end
 
       it 'supports customizes tempest workspace' do
-         is_expected.to contain_exec('tempest-workspace').with(
-           :command     => 'tempest init /tmp/tempest',
-       )
+        is_expected.to contain_exec('tempest-workspace').with(
+          :command => 'tempest init /tmp/tempest',
+        )
+      end
+    end
+
+    context 'with flavor_name parameters' do
+      let :params do
+        {
+          :configure_images => false,
+          :flavor_name      => 'm1.tiny',
+          :flavor_name_alt  => 'm1.nano',
+          :db_flavor_name   => 'm1.micro',
+          :heat_flavor_name => 'm1.small',
+        }
+      end
+
+      it "sets flavor id using setter" do
+        is_expected.to contain_tempest_flavor_id_setter('compute/flavor_ref').with(
+          :ensure            => 'present',
+          :tempest_conf_path => '/var/lib/tempest/etc/tempest.conf',
+          :flavor_name       => 'm1.tiny',
+        )
+        is_expected.to contain_tempest_flavor_id_setter('compute/flavor_ref_alt').with(
+          :ensure            => 'present',
+          :tempest_conf_path => '/var/lib/tempest/etc/tempest.conf',
+          :flavor_name       => 'm1.nano',
+        )
+        is_expected.to contain_tempest_flavor_id_setter('database/db_flavor_ref').with(
+          :ensure            => 'present',
+          :tempest_conf_path => '/var/lib/tempest/etc/tempest.conf',
+          :flavor_name       => 'm1.micro',
+        )
+        is_expected.to contain_tempest_flavor_id_setter('heat_plugin/instance_type').with(
+          :ensure            => 'present',
+          :tempest_conf_path => '/var/lib/tempest/etc/tempest.conf',
+          :flavor_name       => 'm1.small',
+        )
+        is_expected.to contain_tempest_flavor_id_setter('heat_plugin/minimal_instance_type').with(
+          :ensure            => 'present',
+          :tempest_conf_path => '/var/lib/tempest/etc/tempest.conf',
+          :flavor_name       => 'm1.tiny',
+        )
       end
     end
   end
@@ -396,50 +464,45 @@ describe 'tempest' do
        include neutron"
     end
 
-    context 'with when managing tests packages for keystone (required service)' do
-      let :params do
-        { :manage_tests_packages => true }
-      end
-
-      describe "should install keystone tests package" do
-        it { expect { is_expected.to contain_package('python-keystone-tests') } }
-        it { expect { is_expected.to_not contain_package('python-aodh-tests') } }
-      end
+    let :params do
+      { :configure_images      => false,
+        :manage_tests_packages => true }
     end
 
-    context 'with when managing tests packages for aodh (optional service)' do
-      let :params do
-        { :manage_tests_packages => true,
-          :aodh_available        => true }
-      end
-
-      describe "should install aodh tests package" do
-        it { expect { is_expected.to contain_package('python-aodh-tests') } }
+    context 'with when managing tests packages for keystone (required service)' do
+      it "should install keystone tests package" do
+        is_expected.to contain_package('python-keystone-tests')
+        is_expected.to_not contain_package('python-sahara-tests-tempest')
       end
     end
 
     context 'with when managing tests packages for sahara (optional service)' do
-      let :params do
-        { :manage_tests_packages => true,
-          :sahara_available      => true }
+      before :each do
+        params.merge!({ :sahara_available => true })
       end
 
-      describe "should install sahara tests package" do
-        it { expect { is_expected.to contain_package('python-sahara-tests-tempest') } }
+      it "should install sahara tests package" do
+        if platform_params[:python_sahara_tests]
+          is_expected.to contain_package('python-sahara-tests-tempest')
+        end
       end
     end
 
     context 'with when managing tests packages for neutron (optional service)' do
-      let :params do
-        { :manage_tests_packages => true,
-          :neutron_available     => true }
+      before :each do
+        params.merge!({
+          :neutron_available => true,
+          :public_network_id => '4c423fc6-87f7-4e6d-9d3c-abc13058ae5b'
+        })
       end
 
-      describe "should install neutron and *aas tests packages" do
-        it { expect { is_expected.to contain_package('python-neutron-tests') } }
-        it { expect { is_expected.to contain_package('python-neutron-vpnaas-tests') } }
-        it { expect { is_expected.to contain_package('python-neutron-dynamic-routing-tests') } }
-        it { expect { is_expected.to contain_package('python-networking-l2gw-tests-tempest') } }
+      it "should install neutron and *aas tests packages" do
+        if platform_params[:python_neutron_tests]
+          is_expected.to contain_package('python-neutron-tests')
+        end
+        is_expected.to_not contain_package('python-neutron-vpnaas-tests')
+        is_expected.to_not contain_package('python-neutron-dynamic-routing-tests')
+        is_expected.to_not contain_package('python-networking-l2gw-tests-tempest')
       end
     end
   end
@@ -456,32 +519,40 @@ describe 'tempest' do
       let(:platform_params) do
         case facts[:osfamily]
         when 'Debian'
-          { :dev_packages => ['python3-dev',
-                              'libxslt1-dev',
-                              'libxml2-dev',
-                              'libssl-dev',
-                              'libffi-dev',
-                              'patch',
-                              'gcc',
-                              'python3-virtualenv',
-                              'python3-pip' ],
-            :package_name => 'tempest',
-            :pip_command  => 'pip3' }
+          { :dev_packages          => ['python3-dev',
+                                       'libxslt1-dev',
+                                       'libxml2-dev',
+                                       'libssl-dev',
+                                       'libffi-dev',
+                                       'patch',
+                                       'gcc',
+                                       'python3-virtualenv',
+                                       'python3-pip' ],
+            :package_name          => 'tempest',
+            :pip_command           => 'pip3',
+            :python_keystone_tests => 'keystone-tempest-plugin',
+            :python_neutron_tests  => 'neutron-tempest-plugin',
+            :python_sahara_tests   => false }
         when 'RedHat'
-          { :dev_packages => ['python3-devel',
-                              'libxslt-devel',
-                              'libxml2-devel',
-                              'openssl-devel',
-                              'libffi-devel',
-                              'patch',
-                              'gcc'],
-            :package_name => 'openstack-tempest',
-            :pip_command  => 'pip3' }
+          { :dev_packages          => ['python3-devel',
+                                       'libxslt-devel',
+                                       'libxml2-devel',
+                                       'openssl-devel',
+                                       'libffi-devel',
+                                       'patch',
+                                       'gcc'],
+            :package_name          => 'openstack-tempest',
+            :pip_command           => 'pip3',
+            :python_keystone_tests => 'python3-keystone-tests-tempest',
+            :python_neutron_tests  => 'python3-neutron-tests-tempest',
+            :python_sahara_tests   => 'python3-sahara-tests-tempest' }
         end
       end
 
       it_behaves_like 'tempest'
-      it_behaves_like 'tempest with plugins packages'
+      if facts[:operatingsystem] != 'Ubuntu'
+        it_behaves_like 'tempest with plugins packages'
+      end
     end
-   end
+  end
 end
